<?php

namespace Litecms\Flats\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Flats\Models\Flats;

class FlatsPolicy
{

    /**
     * Determine if the given user can view the flats.
     *
     * @param UserPolicy $user
     * @param Flats $flats
     *
     * @return bool
     */
    public function view(UserPolicy $user, Flats $flats)
    {
        if ($user->canDo('flats.flats.view') && $user->isAdmin()) {
            return true;
        }

        return $flats->user_id == user_id() && $flats->user_type == user_type();
    }

    /**
     * Determine if the given user can create a flats.
     *
     * @param UserPolicy $user
     * @param Flats $flats
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('flats.flats.create');
    }

    /**
     * Determine if the given user can update the given flats.
     *
     * @param UserPolicy $user
     * @param Flats $flats
     *
     * @return bool
     */
    public function update(UserPolicy $user, Flats $flats)
    {
        if ($user->canDo('flats.flats.edit') && $user->isAdmin()) {
            return true;
        }

        return $flats->user_id == user_id() && $flats->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given flats.
     *
     * @param UserPolicy $user
     * @param Flats $flats
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Flats $flats)
    {
        return $flats->user_id == user_id() && $flats->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given flats.
     *
     * @param UserPolicy $user
     * @param Flats $flats
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Flats $flats)
    {
        if ($user->canDo('flats.flats.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given flats.
     *
     * @param UserPolicy $user
     * @param Flats $flats
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Flats $flats)
    {
        if ($user->canDo('flats.flats.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
